@@ -1,5 +1,5 @@
 """Top-level package for unesco_reader."""
 
 __author__ = """Luca Picci"""
-__email__ = 'lpicci96@gmail.com'
-__version__ = '0.1.1'
+__email__ = "lpicci96@gmail.com"
+__version__ = '0.2.0'
