@@ -9,11 +9,9 @@ class PATHS:
 
     package = Path(__file__).resolve().parent.parent
 
-    BASE_URL = "https://apimgmtstzgjpfeq2u763lag.blob.core.windows.net/content/MediaLibrary/bdds/"
+    DATASETS = package / "unesco_reader" / "glossaries"
 
-    DATASETS = package / 'unesco_reader' / 'glossaries'
-
-    TEST_FILES = package / 'tests' / 'test_files'
+    TEST_FILES = package / "tests" / "test_files"
 
 
 # =========================================
